@@ -12,14 +12,18 @@
 #' used to setup the PC-prior for sigma.
 #' If a = 0 then U is taken to be the fixed value for sigma.
 #' @param range.fraction numeric to specify the fraction of the range
-#' for the barrier domain. Default value is 0.2.
+#' for the barrier domain. Default value is 0.1.
+#' This has to be specified with care in order to have it small enough
+#' to make it act as barrier but not too small in order to
+#' prevent numerical issues.
 #' @param constr logical to indicate if the integral of the field
 #' over the domain is to be constrained to zero. Default value is FALSE.
 #' @param debug logical indicating if to run in debug mode.
 #' @param verbose logical indicating if to print parameter values.
 #' @param useINLAprecomp logical indicating if is to be used
-#' shared object pre-compiled by INLA. Not considered if
-#' libpath is provided.
+#' shared object pre-compiled by INLA.
+#' This will not be considered if the argument
+#' `libpath` is provided.
 #' @param libpath string to the shared object. Default is NULL.
 #' @details
 #' See the paper.
@@ -27,7 +31,8 @@
 #' @export
 barrierModel.define <-
   function(mesh, barrier.triangles,
-           prior.range, prior.sigma, range.fraction = 0.2,
+           prior.range, prior.sigma,
+           range.fraction = 0.1,
            constr = FALSE, debug = FALSE, verbose = FALSE,
            useINLAprecomp = TRUE, libpath = NULL) {
     stopifnot(all(c(
